CREATE TABLE m_gender (
    gender_code INT PRIMARY KEY,
    gender VARCHAR(255),
    gender_jp VARCHAR(255)
);

CREATE TABLE m_university_major (
    university_major_code INT,
    university_major_jp VARCHAR(255),
    PRIMARY KEY (university_major_code)
);

CREATE TABLE m_age (
    year INT,
    age_code INT,
    age_jp VARCHAR(255),
    age_value INT DEFAULT NULL, -- NULLを許容
    PRIMARY KEY (year, age_code)
);

CREATE TABLE m_employment_status (
    year INT,
    employment_status_code INT,
    employment_status_jp VARCHAR(255),
    PRIMARY KEY (year, employment_status_code)
);

CREATE TABLE m_number_of_employees (
    year INT,
    number_of_employees_code INT,
    number_of_employees_jp VARCHAR(255),
    number_of_employees_value INT DEFAULT NULL,
    PRIMARY KEY (year, number_of_employees_code)
);

CREATE TABLE m_industry (
    year INT,
    industry_code INT,
    industry_jp VARCHAR(255),
    PRIMARY KEY (year, industry_code)
);

CREATE TABLE m_job_title (
    year INT,
    job_title_code INT,
    job_title_jp VARCHAR(255),
    PRIMARY KEY (year, job_title_code)
);

CREATE TABLE m_annual_income (
    year INT,
    annual_income_code INT,
    annual_income_jp VARCHAR(255),
    annual_income_value INT DEFAULT NULL, -- NULLを許容
    PRIMARY KEY (year, annual_income_code)
);

CREATE TABLE m_highest_education_level (
    year INT,
    highest_education_level_code INT,
    highest_education_level_jp VARCHAR(255),
    highest_education_8_level_code INT,
    highest_education_8_level_jp VARCHAR(255),
    PRIMARY KEY (year, highest_education_level_code)
);

CREATE TABLE t_core_attribute (
    year INT,
    response_id INT,
    gender_code INT,
    age_code INT,
    employment_status_code INT,
    number_of_employees_code INT,
    industry_code INT,
    job_title_code INT,
    annual_income_code INT,
    highest_education_level_code INT,
    university_major_code INT,
    PRIMARY KEY (response_id),
    FOREIGN KEY (university_major_code) REFERENCES m_university_major (university_major_code),
    FOREIGN KEY (gender_code) REFERENCES m_gender (gender_code),
    FOREIGN KEY (year,age_code) REFERENCES m_age (year, age_code),
    FOREIGN KEY (year,employment_status_code) REFERENCES m_employment_status (year, employment_status_code),
    FOREIGN KEY (year,number_of_employees_code) REFERENCES m_number_of_employees (year, number_of_employees_code),
    FOREIGN KEY (year,industry_code) REFERENCES m_industry (year, industry_code),
    FOREIGN KEY (year,job_title_code) REFERENCES m_job_title (year, job_title_code),
    FOREIGN KEY (year,annual_income_code) REFERENCES m_annual_income (year, annual_income_code),
    FOREIGN KEY (year,highest_education_level_code) REFERENCES m_highest_education_level (year, highest_education_level_code)
);

CREATE TABLE m_type_prefecture (
    prefecture_type_code INT,
    prefecture_type VARCHAR(255),
    prefecture_type_jp VARCHAR(255),
    PRIMARY KEY (prefecture_type_code)
);

CREATE TABLE m_prefecture (
    prefecture_code INT,
    prefecture_jp VARCHAR(255),
    prefecture_en VARCHAR(255),
    PRIMARY KEY (prefecture_code)
);

CREATE TABLE t_prefecture_wide (
    year INT,
    response_id INT,
    residence_prefecture_code INT DEFAULT NULL,
    work_prefecture_code INT DEFAULT NULL,
    university_prefecture_code INT DEFAULT NULL,
    high_school_prefecture_code INT DEFAULT NULL,
    PRIMARY KEY (response_id),
    FOREIGN KEY (response_id) REFERENCES t_core_attribute (response_id) ON DELETE CASCADE,
    FOREIGN KEY (residence_prefecture_code) REFERENCES m_prefecture (prefecture_code),
    FOREIGN KEY (work_prefecture_code) REFERENCES m_prefecture (prefecture_code),
    FOREIGN KEY (university_prefecture_code) REFERENCES m_prefecture (prefecture_code),
    FOREIGN KEY (high_school_prefecture_code) REFERENCES m_prefecture (prefecture_code)
);

CREATE TABLE t_prefecture_long (
    prefecture_row_id INT,
    year INT,
    response_id INT,
    prefecture_type_code INT,
    prefecture_code INT,
    PRIMARY KEY (prefecture_row_id),
    FOREIGN KEY (response_id) REFERENCES t_core_attribute (response_id) ON DELETE CASCADE,
    FOREIGN KEY (prefecture_code) REFERENCES m_prefecture (prefecture_code),
    FOREIGN KEY (prefecture_type_code) REFERENCES m_type_prefecture (prefecture_type_code)
);

CREATE TABLE m_type_field (
    field_type_code INT,
    field_type VARCHAR(255),
    field_type_jp VARCHAR(255),
    PRIMARY KEY (field_type_code)
);

CREATE TABLE m_field (
    year INT,
    field_code INT,
    field_jp VARCHAR(255),
    PRIMARY KEY (year, field_code)
);

CREATE TABLE m_learning_source (
    year INT,
    learning_source_code INT,
    learning_source_jp VARCHAR(255),
    PRIMARY KEY (year, learning_source_code)
);

CREATE TABLE m_further_study_reason (
    year INT,
    further_study_reason_code INT,
    further_study_reason_jp VARCHAR(255),
    PRIMARY KEY (year, further_study_reason_code)
);

CREATE TABLE t_field_long (
    field_row_id INT,
    year INT,
    response_id INT,
    field_type_code INT,
    field_code INT,
    is_primary_flag BOOLEAN NOT NULL DEFAULT 0,
    PRIMARY KEY (field_row_id),
    FOREIGN KEY (response_id) REFERENCES t_core_attribute (response_id) ON DELETE CASCADE,
    FOREIGN KEY (year, field_code) REFERENCES m_field (year, field_code),
    FOREIGN KEY (field_type_code) REFERENCES m_type_field (field_type_code)
);

CREATE TABLE t_workingfield_and_learningsource_paired_long (
    wflsp_row_id INT,
    year INT,
    response_id INT,
    field_type_code INT,
    field_code INT,
    learning_source_code INT,
    PRIMARY KEY (wflsp_row_id),
    FOREIGN KEY (response_id) REFERENCES t_core_attribute (response_id) ON DELETE CASCADE,
    FOREIGN KEY (year, field_code) REFERENCES m_field (year, field_code),
    FOREIGN KEY (year, learning_source_code) REFERENCES m_learning_source (year, learning_source_code)
);

CREATE TABLE t_furtherstudyfield_and_reason_paired_long (
    fsfr_row_id INT,
    year INT,
    response_id INT,
    field_type_code INT,
    field_code INT,
    further_study_reason_code INT,
    PRIMARY KEY (fsfr_row_id),
    FOREIGN KEY (response_id) REFERENCES t_core_attribute (response_id) ON DELETE CASCADE,
    FOREIGN KEY (year, field_code) REFERENCES m_field (year, field_code),
    FOREIGN KEY (year, further_study_reason_code) REFERENCES m_further_study_reason (year, further_study_reason_code)
);

CREATE TABLE m_type_course (
    course_type_code INT,
    course_type VARCHAR(255),
    course_type_jp VARCHAR(255),
    PRIMARY KEY (course_type_code)
);

CREATE TABLE m_course (
    year INT,
    course_type_code INT,
    course_code INT,
    course_jp VARCHAR(255),
    PRIMARY KEY (year, course_type_code, course_code),
    FOREIGN KEY (course_type_code) REFERENCES m_type_course (course_type_code)
);

CREATE TABLE t_course_long (
    course_row_id INT,
    year INT,
    response_id INT,
    course_type_code INT,
    course_code INT,
    is_primary_flag BOOLEAN NOT NULL DEFAULT 0,
    PRIMARY KEY (course_row_id), 
    FOREIGN KEY (response_id) REFERENCES t_core_attribute (response_id) ON DELETE CASCADE,
    FOREIGN KEY (course_type_code) REFERENCES m_type_course (course_type_code),
    FOREIGN KEY (year, course_type_code, course_code) REFERENCES m_course (year, course_type_code, course_code)
);

CREATE TABLE m_type_job_sub_category (
    job_sub_category_type_code INT,
    job_sub_category_type VARCHAR(255),
    job_sub_category_type_jp VARCHAR(255),
    PRIMARY KEY (job_sub_category_type_code)
);

CREATE TABLE m_job_sub_category (
    year INT,
    job_sub_category_type_code INT,
    job_sub_category_code INT,
    job_sub_category_jp VARCHAR(255),
    PRIMARY KEY (year, job_sub_category_type_code, job_sub_category_code),
    FOREIGN KEY (job_sub_category_type_code) REFERENCES m_type_job_sub_category (job_sub_category_type_code)
);

CREATE TABLE t_job_sub_category_long (
    job_sub_category_row_id INT,
    year INT,
    response_id INT,
    job_sub_category_type_code INT,
    job_sub_category_code INT,
    PRIMARY KEY (job_sub_category_row_id),
    FOREIGN KEY (response_id) REFERENCES t_core_attribute (response_id) ON DELETE CASCADE,
    FOREIGN KEY (job_sub_category_type_code) REFERENCES m_type_job_sub_category (job_sub_category_type_code),
    FOREIGN KEY (year, job_sub_category_type_code, job_sub_category_code) REFERENCES m_job_sub_category (year, job_sub_category_type_code, job_sub_category_code)
);

CREATE TABLE m_job_area (
    year INT,
    job_area_code INT,
    job_area_jp VARCHAR(255),
    PRIMARY KEY (year, job_area_code)
);

CREATE TABLE t_job_area_long (
    job_area_row_id INT,
    year INT,
    response_id INT,
    job_area_code INT,
    is_primary_flag BOOLEAN NOT NULL DEFAULT 0,
    PRIMARY KEY (job_area_row_id),
    FOREIGN KEY (response_id) REFERENCES t_core_attribute (response_id) ON DELETE CASCADE,
    FOREIGN KEY (year, job_area_code) REFERENCES m_job_area (year, job_area_code)
);

CREATE TABLE m_type_it_skill (
    it_skill_type_code INT,
    it_skill_type VARCHAR(255) ,
    it_skill_type_jp VARCHAR(255),
    PRIMARY KEY (it_skill_type_code)
);

CREATE TABLE m_it_skill (
    it_skill_type_code INT,
    it_skill_code INT,
    it_skill_jp VARCHAR(255),
    PRIMARY KEY (it_skill_type_code, it_skill_code),
    FOREIGN KEY(it_skill_type_code) REFERENCES m_type_it_skill (it_skill_type_code)
);

CREATE TABLE m_it_skill_status (
    it_skill_type_code INT,
    it_skill_status_code INT,
    it_skill_status_jp VARCHAR(255),
    PRIMARY KEY (it_skill_type_code, it_skill_status_code),
    FOREIGN KEY(it_skill_type_code) REFERENCES m_type_it_skill (it_skill_type_code)
);


CREATE TABLE t_it_skill_long (
    it_skill_row_id INT,
    year INT,
    response_id INT,
    it_skill_type_code INT,
    it_skill_code INT,
    it_skill_status_code INT,
    PRIMARY KEY (it_skill_row_id),
    FOREIGN KEY (response_id) REFERENCES t_core_attribute (response_id) ON DELETE CASCADE,
    FOREIGN KEY (it_skill_type_code, it_skill_code) REFERENCES m_it_skill (it_skill_type_code, it_skill_code),
    FOREIGN KEY (it_skill_type_code, it_skill_status_code) REFERENCES m_it_skill_status (it_skill_type_code, it_skill_status_code)
);

CREATE TABLE m_researcher_perspective (
    researcher_perspective_code INT,
    researcher_perspective_jp VARCHAR(255),
    PRIMARY KEY (researcher_perspective_code)
);

CREATE TABLE m_researcher_perspective_status (
    researcher_perspective_status_code INT,
    researcher_perspective_status_jp VARCHAR(255),
    PRIMARY KEY (researcher_perspective_status_code)
);

CREATE TABLE t_researcher_perspective_long (
    researcher_perspective_row_id INT,
    year INT,
    response_id INT,
    researcher_perspective_code INT,
    researcher_perspective_status_code INT,
    PRIMARY KEY (researcher_perspective_row_id),
    FOREIGN KEY (response_id) REFERENCES t_core_attribute (response_id) ON DELETE CASCADE,
    FOREIGN KEY (researcher_perspective_code) REFERENCES m_researcher_perspective (researcher_perspective_code),
    FOREIGN KEY (researcher_perspective_status_code) REFERENCES m_researcher_perspective_status (researcher_perspective_status_code)
);

CREATE TABLE m_work_detail (
    year INT,
    work_detail_code INT,
    work_detail_jp VARCHAR(255),
    PRIMARY KEY (year,work_detail_code)
);

CREATE TABLE m_work_detail_status (
    year INT,
    work_detail_status_code INT,
    work_detail_status_jp VARCHAR(255),
    work_detail_status_3v_jp VARCHAR(64),
    PRIMARY KEY (year,work_detail_status_code)
);

CREATE TABLE t_work_detail_long (
    work_detail_row_id INT,
    year INT,
    response_id INT,
    work_detail_code INT,
    work_detail_status_code INT,
    PRIMARY KEY (work_detail_row_id),
    FOREIGN KEY (response_id) REFERENCES t_core_attribute (response_id) ON DELETE CASCADE,
    FOREIGN KEY (year,work_detail_code) REFERENCES m_work_detail (year,work_detail_code),
    FOREIGN KEY (year,work_detail_status_code) REFERENCES m_work_detail_status (year,work_detail_status_code)
);

CREATE TABLE m_higher_education (
    year INT,
    higher_education_code INT,
    higher_education_jp VARCHAR(255),
    PRIMARY KEY (year,higher_education_code)
);

CREATE TABLE m_higher_education_status (
    year INT,
    higher_education_status_code INT,
    higher_education_status_jp VARCHAR(255),
    higher_education_status_3v_jp VARCHAR(64),
    PRIMARY KEY (year,higher_education_status_code)
);

CREATE TABLE t_higher_education_long (
    higher_education_row_id INT,
    year INT,
    response_id INT,
    higher_education_code INT,
    higher_education_status_code INT,
    PRIMARY KEY (higher_education_row_id),
    FOREIGN KEY (response_id) REFERENCES t_core_attribute (response_id) ON DELETE CASCADE,
    FOREIGN KEY (year,higher_education_code) REFERENCES m_higher_education (year,higher_education_code),
    FOREIGN KEY (year,higher_education_status_code) REFERENCES m_higher_education_status (year,higher_education_status_code)
);

CREATE TABLE m_career_change_experience (
    year INT,
    career_change_experience_code INT,
    career_change_experience_jp VARCHAR(255),
    PRIMARY KEY (year, career_change_experience_code)
);

CREATE TABLE t_career_change_experience_long (
    career_change_experience_row_id INT,
    year INT,
    response_id INT,
    career_change_experience_code INT,
    PRIMARY KEY (career_change_experience_row_id),
    FOREIGN KEY (response_id) REFERENCES t_core_attribute (response_id) ON DELETE CASCADE,
    FOREIGN KEY (year, career_change_experience_code) REFERENCES m_career_change_experience (year, career_change_experience_code)
);
